@@ -6,7 +6,7 @@ var indexSectionsWithContent =
   3: "abcdefghijklmnopqrstuvwxyz",
   4: "abcdefghijklmnopqrstuvwx",
   5: "abcdefghijklmnopqrstuvwxyz",
-  6: "cdflpt",
+  6: "abcdefghiklmnoprstuv",
   7: "abcdefghilmnoprstuvwxz",
   8: "abcdefghijklmnopqrstuvwxyz",
   9: "_",
